(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16730,        425]*)
(*NotebookOutlinePosition[     17385,        448]*)
(*  CellTagsIndexPosition[     17341,        444]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sigma scale ratios", "Title"],

Cell[CellGroupData[{

Cell["Code", "Section"],

Cell[CellGroupData[{

Cell["Packages", "Subsection"],

Cell[BoxData[
    \(<< Statistics`DescriptiveStatistics`\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Data loading", "Subsection"],

Cell["\<\
Automatically attempt to load data. If the file maskit-mathematica-2000.txt \
is not in a subdirectory of your home directory, simply change the next \
expression to the line:
<<\"directory\\\\maskit-mathematica-2000.txt\"
where 'directory' is the directory where the file maskit-mathematica-2000.txt \
is kept, and all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<maskit-mathematica-2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(LookupCusp[0] := 2\ I;\)\)], "Input"],

Cell[BoxData[
    \(\(LookupCusp[1] := 2\ I\  + \ 2;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(LookupCusp[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]1\[RightDoubleBracket];\))\) &\) /@ 
        maskitbdy\[LeftDoubleBracket]2\[RightDoubleBracket];\)\)], "Input"],

Cell["\<\
Automatically attempt to load data. If the file tda2000.txt is not in a \
subdirectory of your home directory, simply change the next expression to the \
line:
<<\"directory\\\\tda2000.txt\"
where 'directory' is the directory where the file tda2000.txt is kept, and \
all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<tda2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(TraceDeriv[1] := TraceDeriv[0];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(TraceDeriv[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]2\[RightDoubleBracket];\))\) &\) /@ 
        tracederivatives;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Subsection"],

Cell["\<\
Gives the sequence of rationals p/q whose continued fraction starts with \
initseg and then has repseg repeated subject to q<=2000, the last rational in \
this sequence, and the limit \[Omega].\
\>", "Text"],

Cell[BoxData[
    \(\(QSeq[initseg_, repseq_] := 
        Module[{spseq, ratseq, endrat, omega}, \[IndentingNewLine]spseq = 
            Flatten[{initseg, 
                Table[repseq, {20}]}]; \[IndentingNewLine]ratseq = \
\(FromContinuedFraction[Take[spseq, #1]] &\) /@ 
              Range[Length[spseq]]; \[IndentingNewLine]ratseq = 
            Select[ratseq, 
              Denominator[#1] \[LessEqual] 
                  2000 &]; \[IndentingNewLine]endrat = 
            ratseq\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]; \
\[IndentingNewLine]omega = 
            FromContinuedFraction[
              Join[initseg, {repseq}]]; \[IndentingNewLine]{ratseq, endrat, 
            omega}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(pq[qseq_, n_] := 
        qseq\[LeftDoubleBracket]1, n\[RightDoubleBracket];\)\)], "Input"],

Cell[BoxData[
    \(\(Alpha[qseq_, n_] := 
        Abs[pq[qseq, n] - 
            qseq\[LeftDoubleBracket]3\[RightDoubleBracket]];\)\)], "Input"],

Cell[BoxData[
    \(\(Sigma[qseq_, n_] := 
        Abs[LookupCusp[pq[qseq, n]] - 
              LookupCusp[qseq\[LeftDoubleBracket]2\[RightDoubleBracket]]]/
          Alpha[qseq, n];\)\)], "Input"],

Cell["\<\
Gives the ratio \[Sigma](n+k)/\[Sigma](n) for various values of n given the \
sequence produced by QSeq\
\>", "Text"],

Cell[BoxData[
    \(\(SigmaScaleRatios[qseq_, k_] := 
        Function[n, Sigma[qseq, n + k]/Sigma[qseq, n]] /@ 
          Range[Length[qseq\[LeftDoubleBracket]1\[RightDoubleBracket]] - 
              k];\)\)], "Input"],

Cell["\<\
Drops some of the irrelevant values of the sequence of sigma scale ratios \
(the last one is always wrong, and the first few corresponding to the initial \
segment will also be wrong.\
\>", "Text"],

Cell[BoxData[
    \(\(SSRTest[initseg_, repseq_] := 
        Drop[Drop[SigmaScaleRatios[QSeq[initseg, repseq], Length[repseq]], 
            Length[initseg] - 1], \(-1\)];\)\)], "Input"],

Cell[BoxData[{
    \(\(AllInitSegs[1, amax_] := {{0}};\)\), "\[IndentingNewLine]", 
    \(\(AllInitSegs[lenmax_, amax_] := 
        Module[{ais}, \[IndentingNewLine]ais = 
            AllInitSegs[lenmax - 1, amax]; \[IndentingNewLine]longais = 
            Select[ais, 
              Length[#1] \[Equal] lenmax - 1 &]; \[IndentingNewLine]Join[ais, 
            Sequence @@ \((Function[ap, 
                    Function[seg, Append[seg, ap]] /@ longais] /@ 
                  Range[amax])\)]\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(StatSummary[data_] := {Length -> Length[data], Min -> Min[data], 
        Max -> Max[data], Mean -> Mean[data], 
        Variance -> Variance[data]}\)], "Input"],

Cell[BoxData[
    \(\(ais35 = AllInitSegs[3, 5];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell["\<\
This table shows some statistics from the set of sigma scale ratio \
\[Sigma](n+k)/\[Sigma](n) for all initial segments of length 3 or less with \
partial quotients 5 or less, with repeating segment ( n ) for various values \
of n from 1 to 15.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        Join[{N \[Rule] n}, 
          StatSummary[Flatten[\(SSRTest[#1, {n}] &\) /@ ais35]]], {n, 1, 
          15}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(N \[Rule] 1\), \(Length \[Rule] 330\), \(Min \[Rule] 
              0.891742224944939`\), \(Max \[Rule] 
              1.9837082988023873`\), \(Mean \[Rule] 
              1.2370391268523417`\), \(Variance \[Rule] 
              0.0712642170152128`\)},
          {\(N \[Rule] 2\), \(Length \[Rule] 157\), \(Min \[Rule] 
              1.1905237303388847`\), \(Max \[Rule] 
              1.6473439039063287`\), \(Mean \[Rule] 
              1.401510705780879`\), \(Variance \[Rule] 
              0.018329645384334545`\)},
          {\(N \[Rule] 3\), \(Length \[Rule] 104\), \(Min \[Rule] 
              1.344080342250686`\), \(Max \[Rule] 
              1.6134821138327484`\), \(Mean \[Rule] 
              1.5060451177455894`\), \(Variance \[Rule] 
              0.005756382131995879`\)},
          {\(N \[Rule] 4\), \(Length \[Rule] 79\), \(Min \[Rule] 
              1.3955832099948562`\), \(Max \[Rule] 
              1.5743505206669268`\), \(Mean \[Rule] 
              1.510340437601232`\), \(Variance \[Rule] 
              0.0015323476639418836`\)},
          {\(N \[Rule] 5\), \(Length \[Rule] 60\), \(Min \[Rule] 
              1.3569366782167285`\), \(Max \[Rule] 
              1.4760947156546849`\), \(Mean \[Rule] 
              1.436469824904555`\), \(Variance \[Rule] 
              0.00036453817303091503`\)},
          {\(N \[Rule] 6\), \(Length \[Rule] 51\), \(Min \[Rule] 
              1.270102419070166`\), \(Max \[Rule] 
              1.3500574512042116`\), \(Mean \[Rule] 
              1.3248656201963134`\), \(Variance \[Rule] 
              0.00019315885872777966`\)},
          {\(N \[Rule] 7\), \(Length \[Rule] 45\), \(Min \[Rule] 
              1.1686709022764348`\), \(Max \[Rule] 
              1.222969649311977`\), \(Mean \[Rule] 
              1.2077412487303802`\), \(Variance \[Rule] 
              0.00010033223666478358`\)},
          {\(N \[Rule] 8\), \(Length \[Rule] 38\), \(Min \[Rule] 
              1.0710814085632212`\), \(Max \[Rule] 
              1.109105018659865`\), \(Mean \[Rule] 
              1.0999750844199767`\), \(Variance \[Rule] 
              0.00005985808760517405`\)},
          {\(N \[Rule] 9\), \(Length \[Rule] 34\), \(Min \[Rule] 
              0.9822630494047937`\), \(Max \[Rule] 
              1.0098451412054`\), \(Mean \[Rule] 
              1.0036282347776806`\), \(Variance \[Rule] 
              0.000036883708972783996`\)},
          {\(N \[Rule] 10\), \(Length \[Rule] 30\), \(Min \[Rule] 
              0.9036445859021379`\), \(Max \[Rule] 
              0.9243973556475601`\), \(Mean \[Rule] 
              0.9196551929994263`\), \(Variance \[Rule] 
              0.000023834199702333618`\)},
          {\(N \[Rule] 11\), \(Length \[Rule] 28\), \(Min \[Rule] 
              0.8347235294571486`\), \(Max \[Rule] 
              0.8507997058042915`\), \(Mean \[Rule] 
              0.8466232736615059`\), \(Variance \[Rule] 
              0.00001687029104753088`\)},
          {\(N \[Rule] 12\), \(Length \[Rule] 27\), \(Min \[Rule] 
              0.7743888493818532`\), \(Max \[Rule] 
              0.7872628781368513`\), \(Mean \[Rule] 
              0.7835217357652106`\), \(Variance \[Rule] 
              0.000012353737627858869`\)},
          {\(N \[Rule] 13\), \(Length \[Rule] 23\), \(Min \[Rule] 
              0.721912286895517`\), \(Max \[Rule] 
              0.7318793467897404`\), \(Mean \[Rule] 
              0.7286892157626579`\), \(Variance \[Rule] 
              8.938870474597322`*^-6\)},
          {\(N \[Rule] 14\), \(Length \[Rule] 20\), \(Min \[Rule] 
              0.6751113043366073`\), \(Max \[Rule] 
              0.6834735683038644`\), \(Mean \[Rule] 
              0.6804095101277753`\), \(Variance \[Rule] 
              7.3521556302097845`*^-6\)},
          {\(N \[Rule] 15\), \(Length \[Rule] 18\), \(Min \[Rule] 
              0.6336944396834927`\), \(Max \[Rule] 
              0.6405154063458784`\), \(Mean \[Rule] 
              0.6379037219332848`\), \(Variance \[Rule] 
              5.9650833607203215`*^-6\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
This is the same as the above for the repeating segment (1 n).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        Join[{N \[Rule] n}, 
          StatSummary[Flatten[\(SSRTest[#1, {1, n}] &\) /@ ais35]]], {n, 1, 
          15}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(N \[Rule] 1\), \(Length \[Rule] 299\), \(Min \[Rule] 
              1.179780554375825`\), \(Max \[Rule] 
              1.7759703040334318`\), \(Mean \[Rule] 
              1.4280897056556987`\), \(Variance \[Rule] 
              0.021703535523978416`\)},
          {\(N \[Rule] 2\), \(Length \[Rule] 200\), \(Min \[Rule] 
              1.3544039220515474`\), \(Max \[Rule] 
              1.9591719686691176`\), \(Mean \[Rule] 
              1.5140400157655198`\), \(Variance \[Rule] 
              0.017148772730087778`\)},
          {\(N \[Rule] 3\), \(Length \[Rule] 157\), \(Min \[Rule] 
              1.331813352601087`\), \(Max \[Rule] 
              1.8701296438448436`\), \(Mean \[Rule] 
              1.4509808225434737`\), \(Variance \[Rule] 
              0.016022626047552134`\)},
          {\(N \[Rule] 4\), \(Length \[Rule] 132\), \(Min \[Rule] 
              1.247803114119125`\), \(Max \[Rule] 
              1.7732719062733873`\), \(Mean \[Rule] 
              1.3345519438750852`\), \(Variance \[Rule] 
              0.012671350393425415`\)},
          {\(N \[Rule] 5\), \(Length \[Rule] 119\), \(Min \[Rule] 
              1.1443501544044168`\), \(Max \[Rule] 
              1.6237434026415587`\), \(Mean \[Rule] 
              1.2205229478472794`\), \(Variance \[Rule] 
              0.011510647944452158`\)},
          {\(N \[Rule] 6\), \(Length \[Rule] 105\), \(Min \[Rule] 
              1.0516340849463752`\), \(Max \[Rule] 
              1.4678948237249103`\), \(Mean \[Rule] 
              1.1042317989609438`\), \(Variance \[Rule] 
              0.007318104703797979`\)},
          {\(N \[Rule] 7\), \(Length \[Rule] 96\), \(Min \[Rule] 
              0.9613940753185319`\), \(Max \[Rule] 
              1.3257326911566412`\), \(Mean \[Rule] 
              1.0164111218628407`\), \(Variance \[Rule] 
              0.007014340062372772`\)},
          {\(N \[Rule] 8\), \(Length \[Rule] 89\), \(Min \[Rule] 
              0.8864753584088132`\), \(Max \[Rule] 
              1.2021300769499557`\), \(Mean \[Rule] 
              0.9310970152022996`\), \(Variance \[Rule] 
              0.005291795983495621`\)},
          {\(N \[Rule] 9\), \(Length \[Rule] 83\), \(Min \[Rule] 
              0.8144377237356124`\), \(Max \[Rule] 
              1.0962063528175874`\), \(Mean \[Rule] 
              0.8550951432418973`\), \(Variance \[Rule] 
              0.0038136165382130893`\)},
          {\(N \[Rule] 10\), \(Length \[Rule] 77\), \(Min \[Rule] 
              0.7520608937861387`\), \(Max \[Rule] 
              1.0055374192744615`\), \(Mean \[Rule] 
              0.7926988207071497`\), \(Variance \[Rule] 
              0.003184851537026552`\)},
          {\(N \[Rule] 11\), \(Length \[Rule] 72\), \(Min \[Rule] 
              0.6966086986300009`\), \(Max \[Rule] 
              0.9275938786219388`\), \(Mean \[Rule] 
              0.7428148421012304`\), \(Variance \[Rule] 
              0.0030332615855570753`\)},
          {\(N \[Rule] 12\), \(Length \[Rule] 67\), \(Min \[Rule] 
              0.6540353134418893`\), \(Max \[Rule] 
              0.8590174244637073`\), \(Mean \[Rule] 
              0.6930857231012911`\), \(Variance \[Rule] 
              0.002498337945298813`\)},
          {\(N \[Rule] 13\), \(Length \[Rule] 63\), \(Min \[Rule] 
              0.6115195355824722`\), \(Max \[Rule] 
              0.8050477545809007`\), \(Mean \[Rule] 
              0.6474694337470698`\), \(Variance \[Rule] 
              0.0020196803513659544`\)},
          {\(N \[Rule] 14\), \(Length \[Rule] 59\), \(Min \[Rule] 
              0.5740356687909848`\), \(Max \[Rule] 
              0.7527192310612308`\), \(Mean \[Rule] 
              0.6096945480979957`\), \(Variance \[Rule] 
              0.0017968033839877635`\)},
          {\(N \[Rule] 15\), \(Length \[Rule] 59\), \(Min \[Rule] 
              0.5407703960999823`\), \(Max \[Rule] 
              0.706602504946436`\), \(Mean \[Rule] 
              0.5749305869829675`\), \(Variance \[Rule] 
              0.0015192708526187875`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
This is a plot of the mean value of \[Sigma](n+k)/\[Sigma](n) for the \
repeating segment ( n ) for various values of n from 1 to 15. After \
increasing initially, it goes like 1/n.\
\>", "Text"],

Cell[BoxData[
    \(ListPlot[
      Table[{n, Mean[Flatten[\(SSRTest[#1, {n}] &\) /@ ais35]]}, {n, 1, 
          15}]]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{911, 727},
WindowMargins->{{14, Automatic}, {34, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1799, 55, 23, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[1847, 59, 30, 0, 47, "Subsection"],
Cell[1880, 61, 69, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1986, 67, 34, 0, 31, "Subsection"],
Cell[2023, 69, 376, 7, 71, "Text"],
Cell[2402, 78, 337, 8, 70, "Input"],
Cell[2742, 88, 59, 1, 30, "Input"],
Cell[2804, 91, 67, 1, 30, "Input"],
Cell[2874, 94, 224, 3, 30, "Input"],
Cell[3101, 99, 328, 7, 71, "Text"],
Cell[3432, 108, 321, 8, 70, "Input"],
Cell[3756, 118, 68, 1, 30, "Input"],
Cell[3827, 121, 189, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4053, 129, 26, 0, 31, "Subsection"],
Cell[4082, 131, 217, 4, 52, "Text"],
Cell[4302, 137, 730, 14, 170, "Input"],
Cell[5035, 153, 113, 2, 30, "Input"],
Cell[5151, 157, 145, 3, 30, "Input"],
Cell[5299, 162, 197, 4, 30, "Input"],
Cell[5499, 168, 127, 3, 33, "Text"],
Cell[5629, 173, 219, 4, 30, "Input"],
Cell[5851, 179, 207, 4, 52, "Text"],
Cell[6061, 185, 186, 3, 50, "Input"],
Cell[6250, 190, 527, 9, 130, "Input"],
Cell[6780, 201, 181, 3, 50, "Input"],
Cell[6964, 206, 63, 1, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7076, 213, 26, 0, 33, "Section"],
Cell[7105, 215, 268, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[7398, 224, 170, 4, 30, "Input"],
Cell[7571, 230, 4241, 82, 257, "Output"]
}, Open  ]],
Cell[11827, 315, 86, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[11938, 321, 173, 4, 30, "Input"],
Cell[12114, 327, 4234, 82, 249, "Output"]
}, Open  ]],
Cell[16363, 412, 205, 4, 33, "Text"],
Cell[16571, 418, 131, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

